# Introduction to R Day 5: Basic Phylogenies

## Before we dive in to how R represents phylogenetic trees we are going to make sure everyone remembers how to read a phylogeny, so we are going to work our way through the Tree-Thinking Challenge. A species phylogeny is built using similarities of DNA sequences/morphology between species to represent common ancestry and lines of descent between species. It is important to recognize that phylogenetic trees depict historical relationships, not similarities. Although closely related species tend to be similar to one another, this is not necessarily the case if the rate of evolution is not uniform. 

# This is an empty template that you will fill in during the class, where there is an * it means there is something to do! 

##* Open R and if you haven't already done so, set your working directory to your Intro2R folder and load the ape and geiger packages in R. 

library(ape) # if you haven't already installed it you need install.packages("ape", dependencies=T)

## The ape package is the primary Phylogenetic Comparative Package (PCP) in R written by Emmanuel Paradis and co-authors.  Almost all other PCP's will require ape to run and most will use an object of Class "phylo" which is ape's tree format to input trees into their analyses (most that don't use it provide a function to convert from phylo to their own format). It is therefore important to understand how ape is actually representing the tree. There is a great book available on Ape, written by Emmanuel Paradis "Analysis of Phylogenetics and Evolution with R - Paradis, E (2012) and it is free to download from the UC Davis library! If you are on campus use the link: http://link.springer.com/book/10.1007%2F978-1-4614-1743-9.

#==APE PHYLO OBJECT==

##* We are going to generate a simple 3 taxon tree of bears

text4tr<-"((PolarBear:4, BrownBear:4):3, BlackBear:7);"  # This is a newick string a parenthetical format taxa within the brackets are more closely related so this depicts a sister-relationship between polar and brown bears. After the colon we have the branch lengths, so according to this tree we can see polar and brown bears last shared a common ancestor 4 million years ago (it reality it is much more recent) and they shared a common ancestor with black bears 7 million years ago. 

beartr<-read.tree(text=text4tr) # the read.tree function reads in trees in newick format. 

##* Try plotting the bear tree 

plot(beartr)

##* If you want to see the scaling of the tree you can use the axisPhylo function

axisPhylo()

## You may have been surprised that it automatically plotted a phylogeny eventhough you didn't tell R it was a phylogeny. When you used read.tree to read in the text it generated an object with the class "phylo", anytime you plot a phylo object it automatically calls a special plotting function called plot.phylo. If you want to find out all the options for plotting trees you will have to use ?plot.phylo. Sarah is going to be covering plotting of phylogenies to a much greater extent on the 19th while I am away. 

##* Look at the structure of the bear tree

str(beartr)

## You can see the tree is a list with several components:
# edge - A 2 column matrix where each row represents a branch or edge, the first column represents the ancestral node and the second the descendant node. 
#Nnode - the number of nodes in the tree
# edge.length - (optional) a vector giving the branch lengths in your tree if you have them.
# tip.label - a vector giving the names of the tips, the order corresponds to the numbers in the edge matrix.
# node.label - (optional) a vector giving the names of the nodes (can be bootstrap support etc.).  We don't have any node labels at the moment so this doesn't appear in our tree.

## A tree with no polytomies and n species contains 2n branches and n-1 nodes  

##* The tips are labelled 1:n we can see which species corresponds to which number by looking at the tip.label attribute of the phylo object

beartr$tip.label 

## The 1st is PolarBear, the 2nd BrownBear and the 3rd BlackBear. Nodes are then sequentially numbered starting with the root node as n+1. We can see the default node labels by using the nodelabels function

plot(beartr)
nodelabels()

##* Lets look at the edge matrix and see if we can figure out what it is telling us.

beartr$edge 

##edge is telling us which nodes are connected to which other nodes/tips. 

##* Lets look at edge.length to figure it out.

beartr$edge.length

##edge length is telling us the length of the branches for each element in the edge matrix. 

##* You can make changes to the different components of the phylo object - for example we can add node.labels. Assign the bear tree in a new object thereby making a copy

newbear<-beartr

##* Now make a new element called node.label within the new tree and we can add labels for example the strength of support for the node from the phylogeny building program we used or any other information we want to use

newbear$node.label<-c("1", "0.98")

##* Now multiply the edges lengths by 10 
newbear$edge.length<-beartr$edge.length*10

##* Plot the new tree with an axis and node labels.

plot(newbear)
axisPhylo()
nodelabels()

##* What happened, why didn't we see the new node labels we gave it? Well it is using the default, if we want to use something other than that we have to tell it!

nodelabels(newbear$node.label)

##* We can also make it aesthetically more pleasing by removing the color, removing the frames and then offsetting the label using adj (adj specifies the horizontal and vertical justification of the nodel labels) etc. Again Sarah will likely show you lots of additional possibilities for labelling the nodes with important trait information on the 19th while I am away. 

plot(newbear)
axisPhylo()
nodelabels(newbear$node.label, bg="white", frame="none", adj=c(1,1.2)) 

#== READING, PRUNING & EXPORTING TREES ==

## Outside of R, phylogenies typically come in two formats: nexus and newick, the latter is the format we just used when we generated our text for the bear tree. Ape has different functions to read them in: read.nexus and read.tree, respectively. Once read in, the trees will be stored as phylo objects. If you have multiple trees you must use a nexus format it will be read in as a special "multiPhylo" object,  read.tree will only read in a single tree. 

##* Read in the parrotfish tree and plot it

ptr<-read.nexus("parrotfishtree.nex")

plot(ptr)

## If you want to remove species from the tree you can do so using the drop.tip function in geiger. 

##* Load geiger,  remove "Calotomus spinidens" and "Scarus iseri" and save as a new object

library(geiger)
prunedptr<-drop.tip(ptr, c("Calotomus_spinidens", "Scarus_iseri"))

##* How can we check it worked?

plot(prunedptr)
length(prunedptr$tip.label)
length(ptr$tip.label)

##* How would you change the tip label? for example, we have just realized that your Sparisoma viride was misslabelled and it should be Sparisoma rocha (it is not btw). 

prunedptr$tip.label[prunedptr$tip.label=="Sparisoma_viride"]<-"Sparisoma_rocha"

##* You can save the altered tree from R either as a nexus or newick using the write.nexus and write.tree functions, respectively. Write a newick file.

write.tree(prunedptr, file="prunedparrotfishtree.tre") # you can use the .tre extension or .nex or even .txt

##==MATCHING DATASETS & TREES==
##Oftentimes the species in our datasets and phylogenies are not perfectly overlapping, each contains species not within the other. 

##* Read in the parrotfish morphology making sure to set the species names as row.names

pdat<-read.table("parrotfishesRawMorphology.txt", header=T, row.names=1)

##* What is a quick way of checking if we have the same number of species in the dataset as the pruned tree?

dim(pdat)
prunedptr

##* Using drop.tip and the techniques we learned about in day 3 you could construct a way of making the datasets match by careful matching of the species. However, you will be relieved to know you don't need, to as there is a function in the geiger package that will do it for you. So load geiger if you haven't done so already.


##* Use the treedata function to sort and match your data.

trdat<-treedata(prunedptr, pdat, sort=TRUE)

##* You will notice there is a typo causing one of the species not to match, the tree spelling is correct "Bolbometopon_muricatum", so rename it in the dataset and rerun treedata.

row.names(pdat)[row.names(pdat)=="Bolobometopon_muricatum"]<-"Bolbometopon_muricatum"

trdat<-treedata(prunedptr, pdat, sort=TRUE)

##* look at the structure of the output from treedata and write the new tree and dataset to new files.

str(trdat)
write.nexus(trdat[[1]], file="parrottreematchdata.nex")
write.table(trdat[[2]], file="parrottdatamatchtree.txt")


##=====EXERCISES=====#
# This is going to be short today as we spent more time early on thoroughly reviewing how to read phylogenies.

##* 1) Read in the marsupial tree and dataset 

mdat<-read.table("marsupialmass_continent.txt", header=T, row.names=1)
mtr<-read.tree("marsupialtree.nex")

##* 2) In the tree replace Lagorchestes_hirsutus with "Unknown" and drop "Phascolarctos_cinereus" and match the tree and dataset. 
 
mtr$tip.label[mtr$tip.label=="Lagorchestes_hirsutus"]<-"Unknown"
mtrpruned<-drop.tip(mtr, "Phascolarctos_cinereus") 
 
mmatch<-treedata(mtr, mdat, sort=TRUE)

##* 3) Now convert every branch in the new phylogeny to a length of 1 and plot the tree - what do you predict this will do to the tree topology?

mmatch[[1]]$edge.length<-rep(1, length( mmatch[[1]]$edge.length))
 
plot(mtr, cex=0.5)
 